==> grisbi_1.0.2.orig.tar.bz2: grisbi-1.0.2/src/bet_tab.h <==
/*     Copyright (C) 2007 Dominique Parisot
 * 			zionly@free.org
 * 			http://www.grisbi.org
 *
 *     This program is free software; you can redistribute it and/or modify
 *     it under the terms of the GNU General Public License as published by
 *     the Free Software Foundation; either version 2 of the License, or
 *     (at your option) any later version.
 *
 *     This program is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU General Public License for more details.
 *
 *     You should have received a copy of the GNU General Public License
 *     along with this program; if not, write to the Free Software
 *     Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef _BALANCE_ESTIMATE_TAB_H
#define _BALANCE_ESTIMATE_TAB_H

#include <gtk/gtk.h>

/* START_INCLUDE_H */
#include "bet_data.h"
/* END_INCLUDE_H */

/* START_DECLARATION */
GtkWidget *bet_array_create_page ( void );
void bet_array_create_transaction_from_transfert (struct_transfert_data *transfert);
void bet_array_list_add_new_hist_line ( GtkTreeModel *tab_model,
                        GtkTreeModel *model,
                        GtkTreeIter *iter,
                        GDate *date_min,
                        GDate *date_max );
gboolean bet_array_list_select_path ( GtkWidget *tree_view, GtkTreePath *path );
void bet_array_update_estimate_tab ( gint account_number, gint type_maj );
void bet_array_update_toolbar ( void );
/* END_DECLARATION */

#endif /*_BALANCE_ESTIMATE_TAB_H*/

==> grisbi_1.2.2.orig.tar.bz2: grisbi-1.2.2/src/bet_tab.h <==
/*     Copyright (C) 2007 Dominique Parisot
 * 			zionly@free.org
 * 			http://www.grisbi.org
 *
 *     This program is free software; you can redistribute it and/or modify
 *     it under the terms of the GNU General Public License as published by
 *     the Free Software Foundation; either version 2 of the License, or
 *     (at your option) any later version.
 *
 *     This program is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU General Public License for more details.
 *
 *     You should have received a copy of the GNU General Public License
 *     along with this program; if not, write to the Free Software
 *     Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef _BALANCE_ESTIMATE_TAB_H
#define _BALANCE_ESTIMATE_TAB_H

#include <gtk/gtk.h>

/* START_INCLUDE_H */
#include "bet_data.h"
/* END_INCLUDE_H */

/* START_DECLARATION */
GtkWidget *	bet_array_create_page (void);
void 		bet_array_create_transaction_from_transfert 	(TransfertData *transfert);
void 		bet_array_list_add_new_hist_line 				(GtkTreeModel *tab_model,
															 GtkTreeModel *model,
															 GtkTreeIter *iter,
															 GDate *date_min,
															 GDate *date_max);
gboolean 	bet_array_list_select_path 						(GtkWidget *tree_view,
															 GtkTreePath *path);
gboolean 	bet_array_list_set_largeur_col 					(void);
void 		bet_array_update_estimate_tab 					(gint account_number,
															 gint type_maj);
void 		bet_array_update_toolbar 						(gint toolbar_style);
/* END_DECLARATION */

#endif /*_BALANCE_ESTIMATE_TAB_H*/
